CellarDoor
=======

|Build Status| |Coverage Status|

CellarDoor is a framework for building ReST APIs mostly declaratively. It includes data modeling, data storage, authentication, authorization, serialization and interface protocols. It aims to dramatically reduce the effort involved in creating CRUD APIs without getting in the way of the rest of your application.


Acknowledgements
~~~~~~~~~~~~~~~~
This project makes heavy use of `falcon <http://falconframework.org/>`_. Massive credit to that team. As well, `Eve <http://python-eve.org/>`_ was a big inspiration, philosophically and to a lesser extent `flask-mongorest <https://github.com/elasticsales/flask-mongorest>`_.

.. |Build Status| image:: https://travis-ci.org/cooper-software/cellardoor.svg
   :target: https://travis-ci.org/cooper-software/cellardoor

.. |Coverage Status| image:: https://img.shields.io/coveralls/cooper-software/cellardoor.svg
   :target: https://coveralls.io/r/cooper-software/cellardoor
